@@ -24,8 +24,9 @@
 #from _typeshed import Self
 from enum import Enum
 import datetime
+import time
 from typing import Generator, List, Tuple
-from dhi.platform.base.exceptions import MikeCloudException
+from dhi.platform.base.exceptions import MikeCloudException, MikeCloudRestApiException
 from .generated.metadatagen import AccessLevelV3, DatasetOutputV3, DatasetRecursiveListOutputV3, ItemIdV3, MetadataGenClientV1, MetadataGenClientV2, MetadataGenClientV3, PathActionCreateIfNotExistsV3, PathActionCreateV3, PathActionDeleteV3, PathActionV3, PrepareHierarchyInputV3, PrepareHierarchyOutputV3, UnitIdV3
 from .base import constants
 from .commonmodels import DatasetType
@@ -1012,6 +1013,29 @@ class MetadataClient():
         response = self._client2.GetSasTokenV2(project_id, resourse_id, str(expiration))
         sas_token = response.Body["data"]
         return sas_token
+    
+    def wait_until_dataset_exists(self, dataset_id, timeout:float=7.0, timeout_handler=lambda: (_ for _ in ()).throw(MikeCloudException(f"Dataset did not exists within a specified timeout."))):
+        """Wait until dataset exists in metadata.
+
+        This is a utility method used for example when creating a time series service.
+        The system has to wait until the dataset exists in metadata before it can say it exists.
+
+        :param dataset_id: Dataset id to wait for.
+        :param timeout: Optional. How many seconds to wait before a timeout handler is invoked.
+        :param timeout_handler: Optional callable to call when timeout is reached.
+        """
+        elapsed_time = 0.0
+        sleep_interval = 0.75
+        dataset = None
+        while dataset is None:
+            try:
+                dataset = self.get_dataset(dataset_id)
+            except MikeCloudRestApiException as ex:
+                if ex.status_code == 404 or ex.status_code == 403:
+                    time.sleep(sleep_interval)
+                    elapsed_time += sleep_interval
+                    if(elapsed_time >= timeout):
+                        timeout_handler()
 
 
 if __name__ == '__main__':
