@@ -881,6 +881,9 @@ class VerticalFilterTransformation(TransformationBase):
 class TransferWriterBase:
     def __init__(self, parameters:tuple = ()) -> None:
         self._parameters = list(parameters)
+
+    def __repr__(self) -> str:
+        return "Writer " + str(getattr(self, "name", None))
     
     def add_parameter(self, parameter):
         self._parameters.append(parameter)
@@ -961,6 +964,9 @@ class TransferReaderBase:
     def __init__(self, parameters:tuple = ()) -> None:
         self._parameters = list(parameters)
 
+    def __repr__(self) -> str:
+        return "Reader " + str(getattr(self, "name", None))
+
     def add_parameter(self, parameter):
         self._parameters.append(parameter)
     
@@ -985,7 +991,7 @@ class GenericReader(TransferReaderBase):
     
     @property
     def name(self):
-        self._name
+        return self._name
     
     def with_srid(self, srid:int):
         super()._with_srid_impl(srid)
@@ -1070,7 +1076,7 @@ class TransferPipeline:
         return self
 
     def with_writer_and_parameters(self, writer_name:str, parameters:Tuple=()):
-        self._writer = GenericReader(writer_name, parameters)
+        self._writer = GenericWriter(writer_name, parameters)
         return self
     
     def clear_transformations(self):
